@@ -1,11 +1,17 @@
 subNonStandardCharacters <- function(x,
-   standardCharacters=c(letters, LETTERS, ' ','.', ',', 0:9,
-      '\"', "\'", '-', '_', '(', ')', '[', ']', '\n'),
+   standardCharacters=c(letters, LETTERS, ' ','.', '?', '!', 
+      ',', 0:9, '/', '*', '$', '%', '\"', "\'", '-', '+', '&', '_', ';', 
+      '(', ')', '[', ']', '\n'),
    replacement='_',
    gsubList=list(list(pattern='\\\\\\\\|\\\\', replacement='\"')),
    ... ) {
 ##
-## 1.  gsubList
+## 1.  length(x)<1?
+##
+  nx <- length(x)
+  if(nx<1)return(integer(0))
+##
+## 2.  gsubList
 ##
   xo <- x
   ng <- length(gsubList)
@@ -20,28 +26,34 @@ subNonStandardCharacters <- function(x,
       xo <- gsub(gsLi$pattern, gsLi$replacement, xo)
   }
 ##
-## 2.  x. <- strsplit(x, "", ...)
+## 3.  stringi (formerly iconv)
 ##
-  nx <- length(xo)
-  x. <- strsplit(xo, "", ...)
+#  xo <- iconv(xo, "", "ASCII//TRANSLIT")
+#  returns NAs on Mac OS X 10.10.1 2015.01.25 
+  Encoding(xo)[Encoding(xo)=='unknown'] <- 'latin1'
+  xi <- stringi::stri_trans_general(xo, "Latin-ASCII")
 ##
-## 3.  check each and modify as needed
+## 4.  x. <- strsplit(x, "", ...)
+##
+  x. <- strsplit(xi, "", ...)
+##
+## 5.  check each and modify as needed
 ##
   for(ix in seq(length=nx)){
       gi <- which(!(x.[[ix]] %in% standardCharacters))
       if(length(gi)>0){
-        if(!is.na(xo[ix])){
+        if(!is.na(xi[ix])){
           gi. <- range(gi)
           ni <- length(x.[[ix]])
           xi1 <- paste(x.[[ix]][seq(length=gi.[1]-1)], collapse='')
           xie <- paste(x.[[ix]][seq(from=gi.[2]+1, length=ni-gi.[2])],
                        collapse='')
-          xo[ix] <- paste(xi1, replacement, xie, sep="")
+          xi[ix] <- paste(xi1, replacement, xie, sep="")
         }
       }
   }
 ##
-## 4.  Done
+## 5.  Done
 ##
-  xo
+  xi
 }
